"use strict";
"use client";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const jsx_runtime_1 = require("react/jsx-runtime");
const react_1 = require("react");
const core_1 = require("@replyke/core");
const comments_social_core_1 = require("@replyke/comments-social-core");
const ui_core_react_js_1 = require("@replyke/ui-core-react-js");
const ReplyBanner_1 = __importDefault(require("./ReplyBanner"));
const MentionSuggestions_1 = __importDefault(require("./MentionSuggestions"));
function NewCommentForm({ withEmojis }) {
    const { user } = (0, core_1.useUser)();
    const { project } = (0, core_1.useProject)();
    const giphyActive = project?.integrations.giphy?.active;
    const giphyApiKey = project?.integrations.giphy?.apiKey;
    const { pushMention, createComment, submittingComment, callbacks } = (0, core_1.useCommentSection)();
    const { styleConfig } = (0, comments_social_core_1.useSocialStyleConfig)();
    const [isGiphyVisible, setIsGiphyVisible] = (0, react_1.useState)(false);
    const { backgroundColor, withAvatar, itemsGap, verticalPadding, paddingLeft, paddingRight, authorAvatarSize, placeholderText, textareaTextSize, postButtonText, postButtonFontSize, postButtonFontColor, postButtonFontWeight, } = styleConfig.newCommentFormProps;
    const textAreaRef = (0, react_1.useRef)(null);
    const [content, setContent] = (0, react_1.useState)(""); // We've managed evrything via the ref, but we need this to know if we render a post button or a show gifs button
    const { cursorPosition, isSelectionActive } = (0, ui_core_react_js_1.useTextareaCursorIndicator)({
        textAreaRef,
    });
    const { isMentionActive, loading, mentionSuggestions, handleMentionClick, mentions, addMention, resetMentions, } = (0, core_1.useMentions)({
        content: textAreaRef.current?.value || "",
        setContent: (value) => {
            if (textAreaRef.current)
                textAreaRef.current.value = value;
        },
        focus: () => textAreaRef.current?.focus(),
        cursorPosition,
        isSelectionActive,
    });
    const handleCreateComment = (0, react_1.useCallback)(async () => {
        if (!user) {
            callbacks?.loginRequiredCallback?.();
            return;
        }
        const textArea = textAreaRef.current;
        if (!textArea)
            throw new Error("Can not find textarea");
        const tempContent = textArea.value;
        textArea.value = "";
        try {
            await createComment({ content: tempContent, mentions });
            resetMentions();
        }
        catch (err) {
            textArea.value = tempContent;
            (0, core_1.handleError)(err, "Creating comment failed: ");
        }
    }, [createComment, mentions, resetMentions, callbacks, user]);
    const handleCreateGif = (0, react_1.useCallback)(async (gif) => {
        if (!user) {
            callbacks?.loginRequiredCallback?.();
            return;
        }
        const textArea = textAreaRef.current;
        if (!textArea)
            throw new Error("Can not find textarea");
        textArea.value = "";
        resetMentions();
        setIsGiphyVisible(false);
        try {
            await createComment({ gif, mentions });
        }
        catch (err) {
            (0, core_1.handleError)(err, "Creating comment failed: ");
        }
    }, [createComment, mentions, resetMentions, callbacks, user]);
    (0, react_1.useEffect)(() => {
        if (!pushMention)
            return;
        const textArea = textAreaRef.current;
        if (!textArea)
            throw new Error("Can't find textarea");
        // if (pushMention.id === previousPushMention?.id) return;
        // console.log({
        //   "pushMention.id": pushMention.id,
        //   "previousPushMention?.id": previousPushMention?.id,
        // });
        if (!pushMention.username) {
            (callbacks?.userCantBeMentionedCallback ??
                (() => alert("User has no username")))();
            return;
        }
        addMention(pushMention);
        textArea.value = `@${pushMention.username} ${textArea.value}`;
    }, [pushMention]);
    (0, react_1.useEffect)(() => {
        const handleKeyDown = async (event) => {
            if (event.key === "Enter" && !event.ctrlKey && !event.shiftKey) {
                event.preventDefault(); // Prevent the default Enter behavior
                handleCreateComment();
            }
            // For Ctrl+Enter or Shift+Enter, do nothing and let the event propagate
        };
        const textArea = textAreaRef.current;
        textArea?.addEventListener("keydown", handleKeyDown);
        return () => {
            textArea?.removeEventListener("keydown", handleKeyDown);
        };
    }, [handleCreateComment]);
    const adjustTextareaHeight = () => {
        const textArea = textAreaRef.current;
        if (textArea) {
            textArea.style.height = "auto"; // Reset the height to 'auto' to get the correct scrollHeight
            const baseHeight = 20; // Example base height in pixels. Adjust this value to match your design.
            textArea.style.height = `${Math.max(baseHeight, Math.min(100, textArea.scrollHeight))}px`; // Set the new height based on the content or use the base height if smaller
        }
    };
    // useEffect(() => {
    //   adjustTextareaHeight();
    // }, []);
    (0, react_1.useLayoutEffect)(() => {
        const timeout = setTimeout(() => adjustTextareaHeight(), 500);
        return () => clearTimeout(timeout); // Proper cleanup to clear the timeout
    }, []);
    return ((0, jsx_runtime_1.jsxs)(jsx_runtime_1.Fragment, { children: [giphyActive && giphyApiKey ? ((0, jsx_runtime_1.jsx)(ui_core_react_js_1.GiphyContainer, { giphyApiKey: giphyApiKey, onClickBack: () => setIsGiphyVisible(false), onSelectGif: (selected) => handleCreateGif(selected), visible: isGiphyVisible })) : null, (0, jsx_runtime_1.jsxs)("div", { style: {
                    ...ui_core_react_js_1.resetDiv,
                    position: "relative",
                    backgroundColor,
                }, children: [(0, jsx_runtime_1.jsxs)("div", { style: { width: "100%", position: "relative" }, children: [(0, jsx_runtime_1.jsx)(ReplyBanner_1.default, {}), (0, jsx_runtime_1.jsx)(MentionSuggestions_1.default, { isMentionActive: isMentionActive, isLoadingMentions: loading, mentionSuggestions: mentionSuggestions, handleMentionClick: handleMentionClick })] }), (0, jsx_runtime_1.jsxs)("div", { style: { position: "relative", zIndex: 20, backgroundColor }, children: [withEmojis && ((0, jsx_runtime_1.jsx)(ui_core_react_js_1.EmojiSuggestions, { onEmojiClick: (emoji) => {
                                    const textArea = textAreaRef.current;
                                    if (!textArea)
                                        throw new Error("Can't find textarea");
                                    textArea.value += emoji;
                                    setContent((c) => c + emoji);
                                } })), (0, jsx_runtime_1.jsxs)("div", { style: {
                                    display: "flex",
                                    alignItems: "center",
                                    justifyContent: "flex-end",
                                    gap: itemsGap,
                                    paddingTop: verticalPadding,
                                    paddingBottom: verticalPadding,
                                    paddingLeft,
                                    paddingRight,
                                }, children: [user && withAvatar ? ((0, jsx_runtime_1.jsx)(ui_core_react_js_1.UserAvatar, { user: user, size: authorAvatarSize, borderRadius: authorAvatarSize })) : ((0, jsx_runtime_1.jsx)("div", { style: { height: authorAvatarSize, width: 2 } })), (0, jsx_runtime_1.jsx)("textarea", { id: "replyke-social-textarea", rows: 1, ref: textAreaRef, placeholder: placeholderText, onChange: (e) => setContent(e.target.value), required: true, style: {
                                            ...ui_core_react_js_1.resetTextInput,
                                            width: "100%",
                                            fontSize: textareaTextSize,
                                        } }), content.length === 0 && giphyActive && giphyApiKey ? ((0, jsx_runtime_1.jsx)("button", { type: "button", onClick: () => setIsGiphyVisible(true), disabled: submittingComment, style: {
                                            ...ui_core_react_js_1.resetButton,
                                            border: "none",
                                            outline: "none",
                                            fontWeight: postButtonFontWeight,
                                            fontSize: postButtonFontSize,
                                            color: postButtonFontColor,
                                            cursor: "pointer",
                                        }, children: "GIF" })) : ((0, jsx_runtime_1.jsx)("button", { type: "button", onClick: handleCreateComment, disabled: submittingComment, style: {
                                            ...ui_core_react_js_1.resetButton,
                                            border: "none",
                                            outline: "none",
                                            fontWeight: postButtonFontWeight,
                                            fontSize: postButtonFontSize,
                                            color: postButtonFontColor,
                                            cursor: "pointer",
                                        }, children: postButtonText }))] })] })] })] }));
}
exports.default = NewCommentForm;
//# sourceMappingURL=NewCommentForm.js.map