"use client";
import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import React, { useState } from "react";
import { useCommentVotes, getUserName, useUser, useCommentSection, handleError, } from "@replyke/core";
import { useSocialStyleConfig } from "@replyke/comments-social-core";
import { UserAvatar, FromNow, resetButton, resetDiv, resetP, EllipsisIcon, parseContentWithMentions, } from "@replyke/ui-core-react-js";
import { Replies } from "./Replies";
import HeartButton from "./HeartButton";
import useModalManager from "../../../hooks/useModalManager";
const Comment = React.memo(({ comment: commentFromSection, extraLeftPadding = 0, }) => {
    const { user } = useUser();
    const { openCommentOptionsModal, openCommentOptionsModalOwner } = useModalManager();
    const { handleShallowReply, handleDeepReply, callbacks, highlightedComment, } = useCommentSection();
    const { styleConfig } = useSocialStyleConfig();
    const { horizonalItemsGap, verticalItemsGap, authorAvatarSize, authorFontSize, authorFontWeight, authorFontColor, fromNowFontSize, fromNowFontColor, commentBodyFontSize, commentBodyFontColor, actionsItemGap, replyButtonFontSize, replyButtonFontWeight, replyButtonFontColor, heartIconSize, heartIconEmptyColor, heartIconFullColor, heartIconPaddingBottom, likesCountFontSize, likesCountFontWeight, likesCountFontColor, justNowText, } = styleConfig.commentProps;
    const [hovered, setHovered] = useState(false); // State to track hover
    const [comment, setComment] = useState(commentFromSection);
    const { upvoteComment, removeCommentUpvote } = useCommentVotes({
        comment,
        setComment,
    });
    const handleUpvoteComment = () => {
        if (!user) {
            callbacks?.loginRequiredCallback ||
                (() => alert("Please login first."))();
            return;
        }
        if (!user.username && callbacks?.usernameRequiredCallback) {
            callbacks.usernameRequiredCallback();
            return;
        }
        try {
            upvoteComment();
        }
        catch (err) {
            handleError(err, "Failed to upvote comment");
        }
    };
    const handleRemoveCommentUpvote = () => {
        if (!user) {
            callbacks?.loginRequiredCallback ||
                (() => alert("Please login first."))();
            return;
        }
        try {
            removeCommentUpvote();
        }
        catch (err) {
            handleError(err, "Failed to upvote comment");
        }
    };
    const userUpvotedComment = !!(user && comment.upvotes.includes(user.id));
    return (_jsxs("div", { style: {
            width: "100%",
            paddingTop: 8,
            paddingBottom: 8,
            backgroundColor: highlightedComment?.comment.id === comment.id
                ? "#dbeafe"
                : "transparent",
        }, children: [_jsx("div", { style: {
                    paddingRight: 16,
                    paddingLeft: 16 + extraLeftPadding,
                }, onMouseEnter: () => setHovered(true), onMouseLeave: () => setHovered(false), children: _jsxs("div", { style: {
                        gap: horizonalItemsGap,
                        display: "flex",
                        flexDirection: "row",
                        alignItems: "flex-start",
                    }, children: [_jsx("div", { onClick: () => {
                                if (comment.user.id === user?.id) {
                                    callbacks?.currentUserClickCallback?.();
                                }
                                else {
                                    callbacks?.otherUserClickCallback?.(comment.user.id);
                                }
                            }, children: _jsx(UserAvatar, { user: comment.user, borderRadius: authorAvatarSize, size: authorAvatarSize }) }), _jsxs("div", { style: {
                                gap: verticalItemsGap,
                                flex: 1,
                                display: "flex",
                                flexDirection: "column",
                            }, children: [_jsxs("div", { style: {
                                        display: "flex",
                                        flexDirection: "row",
                                        alignItems: "baseline",
                                        gap: 4,
                                        marginTop: 2,
                                    }, children: [_jsx("div", { onClick: () => {
                                                if (comment.user.id === user?.id) {
                                                    callbacks?.currentUserClickCallback?.();
                                                }
                                                else {
                                                    callbacks?.otherUserClickCallback?.(comment.user.id);
                                                }
                                            }, style: {
                                                ...resetP,
                                                fontWeight: authorFontWeight,
                                                fontSize: authorFontSize,
                                                color: authorFontColor,
                                            }, children: getUserName(comment.user, "username") }), _jsx(FromNow, { time: comment.createdAt, fontSize: fromNowFontSize, color: fromNowFontColor, justNowText: justNowText })] }), comment.content && (_jsx("p", { style: {
                                        ...resetP,
                                        fontSize: commentBodyFontSize,
                                        color: commentBodyFontColor,
                                    }, children: parseContentWithMentions(comment.content, comment.mentions, user?.id, callbacks?.currentUserClickCallback, callbacks?.otherUserClickCallback) })), comment.gif && (_jsx("img", { src: comment.gif.gifUrl, alt: comment.gif.altText, style: {
                                        width: comment.gif.aspectRatio > 1
                                            ? 200
                                            : 200 * comment.gif.aspectRatio,
                                        height: comment.gif.aspectRatio < 1
                                            ? 200
                                            : 200 / comment.gif.aspectRatio,
                                        borderRadius: "0.25rem", // Applies rounded corners to the image itself
                                        overflow: "hidden",
                                        objectFit: "cover",
                                    } })), _jsxs("div", { style: {
                                        ...resetDiv,
                                        gap: actionsItemGap,
                                        display: "flex",
                                        flexDirection: "row",
                                        alignItems: "center",
                                    }, children: [_jsx("button", { onClick: () => comment.parentId
                                                ? handleShallowReply(comment)
                                                : handleDeepReply(comment), style: {
                                                ...resetButton,
                                                color: replyButtonFontColor,
                                                fontSize: replyButtonFontSize,
                                                fontWeight: replyButtonFontWeight,
                                            }, children: "Reply" }), hovered && ( // Conditionally render the EllipsisIcon button
                                        _jsx("button", { onClick: () => user && user.id === comment.userId
                                                ? openCommentOptionsModalOwner?.(comment)
                                                : openCommentOptionsModal?.(comment), children: _jsx(EllipsisIcon, {}) }))] })] }), _jsxs("div", { style: {
                                display: "flex",
                                flexDirection: "column",
                                alignItems: "center",
                            }, children: [_jsx(HeartButton, { userUpvoted: userUpvotedComment, handleUpvote: handleUpvoteComment, handleRemoveUpvote: handleRemoveCommentUpvote, iconSize: heartIconSize, emptyColor: heartIconEmptyColor, fullColor: heartIconFullColor, padding: 4, paddingBottom: heartIconPaddingBottom }), _jsx("div", { style: {
                                        fontSize: likesCountFontSize,
                                        color: likesCountFontColor,
                                        fontWeight: likesCountFontWeight,
                                    }, children: comment.upvotes.length })] })] }) }), !comment.parentId && _jsx(Replies, { commentId: comment.id })] }));
});
export default Comment;
//# sourceMappingURL=Comment.js.map